@@ -9,7 +9,7 @@ use MooX qw/late/;
 
 use PDL ();
 
-our $VERSION = '0.0.11';
+our $VERSION = '0.0.12';
 
 use vars (qw(@fields));
 
@@ -37,13 +37,7 @@ sub attach_to
 sub get_chosen_struct
 {
     my $self = shift;
-    return
-        AI::Pathfinding::OptimizeMultiple::ScanRun->new(
-            {
-                iters => $self->_quota(),
-                scan_idx => $self->_scan_idx()
-            }
-        );
+    return $self->_main->_calc_chosen_scan($self->_scan_idx, $self->_quota);
 }
 
 
@@ -180,7 +174,7 @@ AI::Pathfinding::OptimizeMultiple::IterState - iteration state object.
 
 =head1 VERSION
 
-version 0.0.11
+version 0.0.12
 
 =head1 SUBROUTINES/METHODS
 
